/*
 * @Company: hugeInfo
 * @Author: lwh
 * @Date: 2022-03-29 14:11:57
 * @LastEditTime: 2024-08-21 15:43:25
 * @LastEditors: dminyi 1301963064@qq.com
 * @Version: 1.0.0
 * @Description: 调解总览
 */
import React, { useEffect, useState } from 'react';
import { useNavigate, useLocation, useSearchParams } from 'react-router-dom';
import { Form, Typography, Space, Button, Checkbox, Tooltip } from 'antd';
import { DownloadOutlined } from '@ant-design/icons';
import { ledger_1, ledger_2, ledger_3, ledger_4 } from '../../../assets/images';
import Page from '../../../components/Page';
import * as $$ from '../../../utils/utility';
import { getSessionStorage } from '../../../utils/utility';
import TableView from '../../../components/TableViewCanSort';
import TableSearch from '../../../components/TableSearch';
import publicDataStatus from '../../../status/publicData';
import MyTabs from '../../../components/MyTabs';
import MyImport from '../../../components/MyImport';
import { object } from 'prop-types';
import { P } from '@antv/g2plot';
// 调度总览列表
function getMediateAllDataApi(submitData) {
  return $$.ax.request({ url: 'caseInfo/pageCaseTotal', type: 'get', data: submitData, service: 'mediate' });
}

// 导出成功接口数据
function getPageSuccessApi(submitData) {
  return $$.ax.request({ url: 'caseInfo/xxx', type: 'poet', data: submitData, service: 'mediate' });
}

// 删除数据接口数据
function deleteDraftApi(submitData) {
  return $$.ax.request({ url: 'caseInfo/removeByIdList', type: 'post', data: submitData, service: 'mediate' });
}

//导出查询结果
function exportListToExcelApi(submitData) {
  return $$.ax.request({ url: 'caseInfo/exportListToExcel', type: 'get', data: submitData, service: 'mediate' });
}

const { Link } = Typography;



const MediateAll = () => {
  let location = useLocation();

  let navigate = useNavigate();

  const [searchParams] = useSearchParams();


  const [form] = Form.useForm();

  // 搜索  申请渠道，22_00001-1：机构登记，22_00001-2：小程序，22_00001-3：其他渠道
  const [search, setSearch] = useState({ page: 1, size: 10, canal: '22_00001-1' });

  // tabs标签分页
  const [mediateTab, setMediateTab] = useState('1');

  // 数据
  const [data, setData] = useState({ tableData: [] });

  // 小程序申请数据
  const [miniData, setMiniData] = useState({ tableData: [] })
  const [data3, setData3] = useState({ tableData: [] })
  const [data4, setData4] = useState({ tableData: [] })

  //市人民调解系统转入
  const [otherData, setOtherData] = useState({ tableData: [] })

  //网格化服务平台转入
  const [platformData, setPlatformData] = useState({ tableData: [] })

  // 调解组织select框数据
  const [adjustOrgData, setAdjustOrgData] = useState([]);

  // table选择数据
  const [selectedRowsObj, setSelectedRowsObj] = useState({});

  //自定义排序
  const [page, setPage] = useState(1);
  const [size, setSize] = useState(10);
  const [sortType, setSortType] = useState(1);
  const [sortFieldParm, setSortFieldParm] = useState(1);

  //自定义排序
  function getOrderPara(field, order) {
    if (field === 'acceptTime') {
      setSortFieldParm(1);
      if (order === 'descend') {
        setSortType(1);
        handleSearch('changePage', [page, size, 1], '', mediateTab);
      }
      if (order === 'ascend') {
        handleSearch('changePage', [page, size, 2], '', mediateTab);
        setSortType(2);
      }
    }
    if (field === 'mediEndTime') {
      setSortFieldParm(2);
      if (order === 'descend') {
        handleSearch('changePage', [page, size, 3], '', mediateTab);
        setSortType(3);
      }
      if (order === 'ascend') {
        handleSearch('changePage', [page, size, 4], '', mediateTab);
        setSortType(4)
      }
    }
    if (typeof order === 'undefined') {
      handleSearch('changePage', [page, size], '', mediateTab);
      setSortType('');
    }
  };


  // 查看，签收跳转
  function handleJump(record) {
    $$.setSessionStorage(location.pathname, {
      search,
      title: '详情',
      breadcrumbData: [{ title: '调解总览', url: location.pathname }, { title: '查看' }],
      tableActive: record.id,
      pageFrom: 'mediateAll',
    });
    navigate(`/mediate/caseDetail?caseId=${record.id}&mediateTab=${mediateTab}&judicialId=${record.judicialld}&back=${location.pathname}`);

  }
  //修改页面
  function modifyJump(record) {
    $$.setSessionStorage(location.pathname, {
      search,
      title: '案件修改',
      breadcrumbData: [{ title: '调解总览', url: location.pathname }, { title: '案件修改' }],
      tableActive: record.id,
      pageFrom: 'Modify',
    });
    navigate(`/mediate/caseDetail?caseId=${record.id}&mediateTab=${mediateTab}&judicialId=${record.judicialld}&back=${location.pathname}`);
  }

  // 搜索 or 重置
  function handleSearch(type, data, tableActive, tab) {
    if (type === 'recovery') {
      // 案件详情返回时恢复跳转前查询
      let obj = { ...data };
      if (obj.acceptTime) {
        obj.acceptTime = [$$.myMoment(obj.acceptStart), $$.myMoment(obj.acceptEnd)];
      }
      if (obj.mediEndTime) {
        obj.mediEndTime = [$$.myMoment(obj.mediEndTimeStart), $$.myMoment(obj.mediEndTimeEnd)];
      }
      form.setFieldsValue(obj);
      tab == '1' && getMediateAllData({ ...data, canal: '22_00001-1', sortType }, tableActive);
      tab == '2' && getMediateAllMiniData({ ...data, canal: '22_00001-2', sortType }, tableActive);
      tab == '3' && getMediateAllOtherData({ ...data, canal: '22_00001-6', sortType }, tableActive);
      tab == '4' && getMediatePlatformData({ ...data, canal: '22_00001-5', sortType }, tableActive);
      return;
    }
    if (type === 'reset') {
      form.resetFields();
      // 22_00001-1：机构登记，22_00001-2：小程序，22_00001-3：其他渠道
      tab == '1' && getMediateAllData({ page: 1, size: 10, canal: '22_00001-1', sortType });
      tab == '2' && getMediateAllMiniData({ page: 1, size: 10, canal: '22_00001-2', sortType });
      tab == '3' && getMediateAllOtherData({ page: 1, size: 10, canal: '22_00001-6', sortType });
      tab == '4' && getMediatePlatformData({ page: 1, size: 10, canal: '22_00001-5', sortType });

      return;
    }
    if (type === 'search' || type === 'changePage') {
      let values = form.getFieldsValue();
      $$.changeTimeFormat(values, 'acceptTime', 'acceptStart', 'acceptEnd');
      $$.changeTimeFormat(values, 'mediEndTime', 'mediEndTimeStart', 'mediEndTimeEnd');
      let obj = type === 'changePage' ? { page: data[0], size: data[1], sortType: data[2] } : { page: 1, sortType: data[2] };
      tab == '1' && getMediateAllData({ ...search, ...values, ...obj, canal: '22_00001-1' });
      tab == '2' && getMediateAllMiniData({ ...search, ...values, ...obj, canal: '22_00001-2' });
      tab == '3' && getMediateAllOtherData({ ...search, ...values, ...obj, canal: '22_00001-6' });
      tab == '4' && getMediatePlatformData({ ...search, ...values, ...obj, canal: '22_00001-5' });

    }
  }

  // 获取数据
  async function getMediateAllData(submitData, tableActive) {
    global.setSpinning(true);
    const res = await getMediateAllDataApi(submitData);
    global.setSpinning(false);
    if (res.type) {
      const canal = submitData.canal;
      if (canal == '22_00001-1') {
        setData({ total: res.data.totalElements, tableData: res.data.content, tableActive });
      } else if (canal == '22_00001-2') {
        setMiniData({ total: res.data.totalElements, tableData: res.data.content, tableActive });
      }
      setSearch(submitData);
    }
  }

  // 获取小程序申请数据
  async function getMediateAllMiniData(submitData, tableActive) {
    global.setSpinning(true);
    const res = await getMediateAllDataApi(submitData);
    global.setSpinning(false);
    if (res.type) {
      setMiniData({ total: res.data.totalElements, tableData: res.data.content, tableActive });
      setSearch(submitData);
    }
  }


  //市人民调解系统转入数据
  async function getMediateAllOtherData(submitData, tableActive) {
    global.setSpinning(true);
    const res = await getMediateAllDataApi(submitData);
    global.setSpinning(false);
    if (res.type) {
      setOtherData({ total: res.data.totalElements, tableData: res.data.content, tableActive });
      setSearch(submitData);
    }
  }

  //市人民调解系统转入数据
  async function getMediatePlatformData(submitData, tableActive) {
    global.setSpinning(true);
    const res = await getMediateAllDataApi(submitData);
    global.setSpinning(false);
    if (res.type) {
      setPlatformData({ total: res.data.totalElements, tableData: res.data.content, tableActive });
      setSearch(submitData);
    }
  }

  // 选择导出内容
  function onSelectChange(selectedRowKeys, selectedRows) {
    let obj = {};
    obj[search.page] = { selectedRowKeys, selectedRows };

    setSelectedRowsObj({ ...selectedRowsObj, ...obj });
  }

  //草稿 获取table选择数据
  function handleGetSelectedRowKeys(type) {
    let arr = [];
    for (let item in selectedRowsObj) {
      arr = arr.concat(selectedRowsObj[item][type]);
    }
    return arr;
  }

  //批量导出
  async function showDrawer(list) {
    let result = list.join(',');
    $$.modalInfo({
      title: '批量导出确认',
      content: <span>确认导出当前选中的案件信息吗？</span>,
      okText: '确定导出',
      cancelText: '我再想想',
      onOk: async () => {
        let userId = $$.getLocal('customerSystemUser')?.userId;
        window.location.href = `${$$.appUrl.baseUrl}/${$$.appUrl.mediate}/api/v1/caseInfo/exportListToExcel?userId=${userId}&ids=${result}`;
      },
    });
  }

  // 导出查询结果
  async function searchTotal() {

    let list = [];
    mediateTab == '1' && (list = data.tableData || []);
    mediateTab == '2' && (list = miniData.tableData || []);
    mediateTab == '3' && (list = otherData.tableData || []);
    mediateTab == '4' && (list = platformData.tableData || []);
    if (list.length == 0) {
      $$.info({ type: 'error', content: '暂无数据可以导出' });
    } else {
      $$.modalInfo({
        title: '导出查询结果确认',
        content: <span>确认导出当前查询结果包含的<span className='ledger-main-title'>全部案件信息</span> 吗？</span>,
        okText: '确定导出',
        cancelText: '我再想想',
        onOk: async () => {
          let data = JSON.parse(JSON.stringify(search));
          let params = $$.getQueryObj(data);
          let userId = $$.getLocal('customerSystemUser')?.userId;
          let sortField = sortFieldParm || '';
          let sortType1 = sortType || '';
          // window.open(`${$$.appUrl.baseUrl}${$$.appUrl.mediate}/api/v1/caseInfo/exportListToExcel?${params}userId${userId}`);
          // console.log('data', `${$$.appUrl.baseUrl}${$$.appUrl.mediate}/api/v1/caseInfo/exportListToExcel?${params}userId${userId}`);
          window.location.href = `${$$.appUrl.baseUrl}/${$$.appUrl.mediate}/api/v1/caseInfo/exportListToExcel?${params}userId=${userId}&sortField=${sortField}&sortType=${sortType1}`;
        },
      });
    }
  }

  // 批量删除
  async function handleDelete(list) {
    $$.modalInfo({
      title: '案件删除确认',
      content: '删除后案件将无法找回，案件经办人也将无法查看到案件信息，确定删除本次选中的案件信息吗？',
      okText: '确定删除',
      cancelText: '我再想想',
      onOk: async () => {
        global.setSpinning(true);
        const res = await deleteDraftApi(list);
        global.setSpinning(false);
        if (res.type) {
          $$.infoSuccess({ content: '删除成功' });
          setSelectedRowsObj({});
          handleSearch('reset', '', '', mediateTab);
        }
      },
    });
  }

  // 初始化
  useEffect(() => {
    publicDataStatus.getUnitData((data) => setAdjustOrgData(data));
    let returnRouteData = $$.getSessionStorage(location.pathname);
    if (searchParams.get('isBack') && !!returnRouteData) {
      searchParams.get('mediateTab') && setMediateTab(searchParams.get('mediateTab'));
      handleSearch('recovery', returnRouteData.search, returnRouteData.tableActive, '1');
      handleSearch('recovery', returnRouteData.search, returnRouteData.tableActive, '2');
      handleSearch('recovery', returnRouteData.search, returnRouteData.tableActive, '3');
      handleSearch('recovery', returnRouteData.search, returnRouteData.tableActive, '4');

    } else {
      handleSearch('reset', '', '', '1');
      handleSearch('reset', '', '', '2');
      handleSearch('reset', '', '', '3');
      handleSearch('reset', '', '', '4');
    }
    if (!!returnRouteData) {
      $$.clearSessionStorage(location.pathname);
    }
  }, []);

  const columns = [
    { title: '调解案号', dataIndex: 'caseNo', key: 'caseNo' },
    {
      title: '纠纷受理时间', width: 80, dataIndex: 'acceptTime', defaultSortOrder: 'descend', order: 'ascend',
      sorter: { compare: (a, b) => { } }
    },
    { title: '调解进度', width: 80, dataIndex: 'processName', key: 'processName' },

    { title: '申请人', width: 80, dataIndex: 'plaintiffs' },
    { title: '被申请人', width: 80, dataIndex: 'defendants' },
    { title: '纠纷类型', width: 80, dataIndex: 'caseTypeName' },
    { title: '调解类型', width: 80, dataIndex: 'mediTypeName' },
    { title: '调解组织', width: 120, dataIndex: 'mediateUnitName' },
    { title: '调解员', width: 60, dataIndex: 'mediator' },
    { title: '协助调解员', width: 80, width: 120, dataIndex: 'otherMediator', render: (text, record) => <Tooltip placement="topLeft" title={text ? text.replace('，', '/') : '-'}>{text ? text.replace('，', '/') : '-'}</Tooltip> },
    {
      title: '调解结束时间', width: 80, dataIndex: 'mediEndTime', key: 'mediEndTime', order: 'ascend',
      sorter: { compare: (a, b) => { } }
    },
    {
      title: '调解结果',
      dataIndex: 'mediResultName',
      width: 80,
      render: (text, record) =>
        !text ? '-' : <div className={`public-tag public-tag-${record.mediResult === '22_00025-1' ? 'tagGreen' : 'tagRed'}`}>{text}</div>,
    },
    // { title: '纠纷发生地', dataIndex: 'addr' },
    // { title: '申请渠道', dataIndex: 'canalName' },
    {
      title: '归档结果',
      width: 80,
      dataIndex: 'fileStatusName',
    },
    {
      title: '操作',
      dataIndex: 'action',
      width: 90,
      render: (_, record) => {
        return (
          <Space size="middle">
            <Link onClick={() => handleJump(record)}>查看</Link>
            {record.fileStatusName === '已归档' && <Link onClick={() => modifyJump(record)}>修改</Link>}
          </Space>
        );
      },
    },
  ];

  const countData = data.total || 0;

  const countMiniData = miniData.total || 0;

  const countOtherData = otherData.total || 0;

  const countPlatformData = platformData.total || 0;

  const selectedRowKeys = handleGetSelectedRowKeys('selectedRowKeys');



  return (
    <Page pageHead={{ title: '调解总览（一本账）', subtitle: <span>汇总查看名下{<span className='ledger-main-title'>不同渠道</span>}进入多元化解平台的矛盾纠纷案件，形成白云区矛盾纠纷统一台账管理中心</span> }}>
      <div className="ledger-main" style={{ marginBottom: selectedRowKeys?.length > 0 ? '56px' : '0' }}>
        <div className="myMediation-search">
          <TableSearch
            labelLength={6}
            form={form}
            itemData={[
              { type: 'Input', name: 'plaintiffs', label: '申请人' },
              { type: 'Input', name: 'defendants', label: '被申请人' },
              { type: 'RangePicker', name: 'acceptTime', label: '纠纷受理时间' },
              { type: 'Input', name: 'caseNo', label: '调解案号' },
              { type: 'Select', name: 'mediResult', label: '调解结果', selectdata: $$.options.mediResult },
              { type: 'RangePicker', name: 'mediEndTime', label: '调解结束时间' },
              { type: 'TreeSelect', name: 'mediateUnitId', label: '调解组织', placeholder: '查询调解组织名称', treedata: adjustOrgData },
              { type: 'Input', name: 'mediator', label: '调解员' },
              { type: 'Input', name: 'otherMediator', label: '协助调解员' },
              { type: 'Select', name: 'caseType', label: '纠纷类型', selectdata: $$.caseOptions.caseCause },
              { type: 'Select', name: 'process', label: '调解进度', selectdata: $$.options.process },
              { type: 'Select', name: 'fileStatus', label: '归档结果', selectdata: $$.options.fileStatus },
              { type: 'Input', name: 'mediateBookNo', label: '诉前调书号', placeholder: '输入查询诉前调书号' },
              { type: 'Input', name: 'mediateNo', label: '诉前调解案号', placeholder: '输入查询诉前调解案号' },
              { type: 'Select', name: 'mediType', label: '调解类型', selectdata: $$.options.mediateType },
              // { type: 'Input', name: 'addr', label: '纠纷发生地' },
            ]}
            handleReset={() => handleSearch('reset', '', '', mediateTab)}
            handleSearch={() => handleSearch('search', '', '', mediateTab)}
          />
        </div>
        <div className="pageTabs">
          <MyTabs
            tabs={[
              { key: '1', label: `机构登记(${$$.showMoreNum(countData)})` },
              { key: '2', label: `小程序申请(${$$.showMoreNum(countMiniData)})` },
              { key: '3', label: `市人民调解系统转入(${$$.showMoreNum(countOtherData)})` },
              { key: '4', label: `网格化服务平台转入(${$$.showMoreNum(countPlatformData)})` },
            ]}
            activeKey={mediateTab}
            onChange={(activeKey) => {
              setMediateTab(activeKey);
              handleSearch('reset', '', '', activeKey);
            }}
          />
        </div>
        <div className='ledger-main-mould' style={{ marginBottom: '12px', padding: '10px 16px', backgroundColor: "#ffffff", boxShadow: '0px 2px 8px 0px rgba(0,0,0,0.15)' }}>
          <div className='ledger-main-mould-img'>
            <img src={ledger_2} alt="" />
          </div>
          {mediateTab == '1' && <span style={{ lineHeight: '22px' }}><span className='ledger-main-title'>机构登记</span>指调解机构（组织）在多元化解平台中通过<span className='ledger-main-title'>导入/个案登记</span>方式，产生的所有案件信息</span>}
          {mediateTab == '2' && <span style={{ lineHeight: '22px' }}><span className='ledger-main-title'>小程序申请</span>指辖区当事人使用<span className='ledger-main-title'>云法调解微信小程序</span>自行登记纠纷并申请调解，产生的所有案件信息（说明：由于小程序案件为当事人申请，暂不允许调解组织后台删除）</span>}
          {mediateTab == '3' && <span style={{ lineHeight: '22px' }}><span className='ledger-main-title'>市人民调解系统转入</span>指由<span className='ledger-main-title'>广州市人民调解信息管理系统</span>进行受理后，转入多元化解平台，产生的所有案件信息</span>}
          {mediateTab == '4' && <span style={{ lineHeight: '22px' }}><span className='ledger-main-title'>网格化服务平台转入</span>指由<span className='ledger-main-title'>广州市白云区网格化服务管理平台</span>进行受理后，转入多元化解平台，产生的所有案件信息</span>}
        </div>
        <div className="pageTable">
          {/* 机构登记 */}
          {mediateTab === '1' && <TableView
            onValueChange={getOrderPara}
            showHeader
            title="查询结果"
            buttonAction={[
              <Space>
                <Button icon={<DownloadOutlined />} type="primary" ghost onClick={() => searchTotal()}>导出查询结果</Button>
              </Space>
            ]}
            columns={columns}
            dataSource={data.tableData}
            rowKey="id"
            rowSelection={mediateTab == '1' && { selectedRowKeys, onChange: onSelectChange }}
            pagination={{
              current: page,
              pageSize: size,
              total: data.total,
              onChange: (page, pageSize) => {
                setPage(page);
                setSize(pageSize);
                handleSearch('changePage', [page, pageSize, sortType], '', mediateTab);
              }
            }}
            rowClassName={(record) => (record.id === data.tableActive ? 'tableRowActive' : '')}
          />}
          {/* 小程序 */}
          {mediateTab === '2' && <TableView
            onValueChange={getOrderPara}
            showHeader
            title="查询结果"
            buttonAction={[
              <Space>
                <Button icon={<DownloadOutlined />} type="primary" ghost onClick={() => searchTotal()}>导出查询结果</Button>
              </Space>
            ]}
            columns={columns}
            dataSource={miniData.tableData}
            pagination={{
              current: search.page,
              pageSize: search.size,
              total: miniData.total,
              onChange: (page, pageSize) => {
                setPage(page);
                setSize(pageSize);
                handleSearch('changePage', [page, pageSize], '', mediateTab)
              }
            }}
            rowClassName={(record) => (record.id === miniData.tableActive ? 'tableRowActive' : '')}

          />}
          {/* 市人民调解系统转入 */}
          {mediateTab === '3' && <TableView
            onValueChange={getOrderPara}
            showHeader
            title="查询结果"
            buttonAction={[
              <Space>
                <Button icon={<DownloadOutlined />} type="primary" ghost onClick={() => searchTotal()}>导出查询结果</Button>
              </Space>
            ]}
            columns={columns}
            dataSource={otherData.tableData}
            pagination={{
              current: search.page,
              pageSize: search.size,
              total: otherData.total,
              onChange: (page, pageSize) => {
                setPage(page)
                setSize(pageSize);
                handleSearch('changePage', [page, pageSize], '', mediateTab)
              },
            }}
            rowClassName={(record) => (record.id === otherData.tableActive ? 'tableRowActive' : '')}
          />}
          {/* 网格化服务平台转入 */}
          {mediateTab === '4' && <TableView
            onValueChange={getOrderPara}
            showHeader
            title="查询结果"
            buttonAction={[
              <Space>
                <Button icon={<DownloadOutlined />} type="primary" ghost onClick={() => searchTotal()}>导出查询结果</Button>
              </Space>
            ]}
            columns={columns}
            dataSource={platformData.tableData}
            pagination={{
              current: search.page,
              pageSize: search.size,
              total: platformData.total,
              onChange: (page, pageSize) => {
                setPage(page);
                setSize(pageSize);
                handleSearch('changePage', [page, pageSize], '', mediateTab)
              }
            }}
            rowClassName={(record) => (record.id === platformData.tableActive ? 'tableRowActive' : '')}
          />}
        </div>
        {selectedRowKeys.filter(d => d).length > 0 && (
          <div className="ledger-main-excel">
            <Space size="middle">
              <Checkbox
                onChange={(e) => {
                  if (!e.target.checked) {
                    setSelectedRowsObj({});
                  }
                }}
                checked={(selectedRowKeys.filter(d => d).length = data.total)}
                indeterminate={selectedRowKeys.filter(d => d).length < data.total}
              >
                已选{selectedRowKeys.filter(d => d).length}项
              </Checkbox>
              <Link onClick={() => setSelectedRowsObj({})}>取消</Link>
            </Space>
            <div>
              <Space size="middle">
                <Button onClick={() => showDrawer(handleGetSelectedRowKeys('selectedRowKeys'))} type="primary" style={{ marginLeft: '24px' }}>
                  确定导出
                </Button>
                <Button type="primary" ghost onClick={() => handleDelete(handleGetSelectedRowKeys('selectedRowKeys'))}>删除</Button>
              </Space>
            </div>
          </div>
        )}
      </div>
    </Page>
  );
};

export default MediateAll;
